@@ -837,8 +837,8 @@ static void viaTexSubImage2D(GLcontext *ctx,
                              struct gl_texture_image *texImage)
 {
    struct via_context *vmesa = VIA_CONTEXT(ctx);
-  
-   VIA_FLUSH_DMA(vmesa);
+
+   viaWaitIdle(vmesa, GL_TRUE);
    vmesa->clearTexCache = 1;
 
    _mesa_store_texsubimage2d(ctx, target, level, xoffset, yoffset, width,
@@ -874,7 +874,7 @@ static void viaTexSubImage1D(GLcontext *ctx,
 {
    struct via_context *vmesa = VIA_CONTEXT(ctx);
 
-   VIA_FLUSH_DMA(vmesa);
+   viaWaitIdle(vmesa, GL_TRUE);
    vmesa->clearTexCache = 1;
 
    _mesa_store_texsubimage1d(ctx, target, level, xoffset, width,
