@@ -83,7 +83,8 @@ extern DeviceAssocRec mouse_assoc;
 #endif
 
 #if (defined(i386) || defined(__i386__)) && \
-    (defined(__FreeBSD__) || defined(__NetBSD__) || defined(linux) || \
+    (defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || \
+     defined(__NetBSD__) || defined(linux) || \
      (defined(SVR4) && !defined(sun)) || defined(__GNU__))
 #define SUPPORT_PC98
 #endif
@@ -1005,25 +1006,40 @@ configServerFlags(XF86ConfFlagsPtr flagsconf, XF86OptionPtr layoutopts)
 	xf86Info.estimateSizesAggressively = i;
     else
 	xf86Info.estimateSizesAggressively = 0;
-	
+
+/* Make sure that timers don't overflow CARD32's after multiplying */
+#define MAX_TIME_IN_MIN (0x7fffffff / MILLI_PER_MIN)
+
     i = -1;
     xf86GetOptValInteger(FlagOptions, FLAG_SAVER_BLANKTIME, &i);
-    if (i >= 0)
+    if ((i >= 0) && (i < MAX_TIME_IN_MIN))
 	ScreenSaverTime = defaultScreenSaverTime = i * MILLI_PER_MIN;
+    else if (i != -1)
+	xf86ConfigError("BlankTime value %d outside legal range of 0 - %d minutes",
+			i, MAX_TIME_IN_MIN);
 
 #ifdef DPMSExtension
     i = -1;
     xf86GetOptValInteger(FlagOptions, FLAG_DPMS_STANDBYTIME, &i);
-    if (i >= 0)
+    if ((i >= 0) && (i < MAX_TIME_IN_MIN))
 	DPMSStandbyTime = defaultDPMSStandbyTime = i * MILLI_PER_MIN;
+    else if (i != -1)
+	xf86ConfigError("StandbyTime value %d outside legal range of 0 - %d minutes",
+			i, MAX_TIME_IN_MIN);
     i = -1;
     xf86GetOptValInteger(FlagOptions, FLAG_DPMS_SUSPENDTIME, &i);
-    if (i >= 0)
+    if ((i >= 0) && (i < MAX_TIME_IN_MIN))
 	DPMSSuspendTime = defaultDPMSSuspendTime = i * MILLI_PER_MIN;
+    else if (i != -1)
+	xf86ConfigError("SuspendTime value %d outside legal range of 0 - %d minutes",
+			i, MAX_TIME_IN_MIN);
     i = -1;
     xf86GetOptValInteger(FlagOptions, FLAG_DPMS_OFFTIME, &i);
-    if (i >= 0)
+    if ((i >= 0) && (i < MAX_TIME_IN_MIN))
 	DPMSOffTime = defaultDPMSOffTime = i * MILLI_PER_MIN;
+    else if (i != -1)
+	xf86ConfigError("OffTime value %d outside legal range of 0 - %d minutes",
+			i, MAX_TIME_IN_MIN);
 #endif
 
     i = -1;
@@ -1090,6 +1106,11 @@ configInputKbd(IDevPtr inputp)
   MessageType from = X_DEFAULT;
   Bool customKeycodesDefault = FALSE;
   int verb = 0;
+#if defined(XQUEUE)
+  char *kbdproto = "Xqueue";
+#else
+  char *kbdproto = "standard";
+#endif
 
   /* Initialize defaults */
   xf86Info.xleds         = 0L;
@@ -1130,16 +1151,25 @@ configInputKbd(IDevPtr inputp)
   xf86Info.xkbgeometry   = NULL;
 #endif
 
-  s = xf86SetStrOption(inputp->commonOptions, "Protocol", "standard");
+  s = xf86SetStrOption(inputp->commonOptions, "Protocol", kbdproto);
   if (xf86NameCmp(s, "standard") == 0) {
      xf86Info.kbdProc    = xf86KbdProc;
      xf86Info.kbdEvents  = xf86KbdEvents;
      xfree(s);
   } else if (xf86NameCmp(s, "xqueue") == 0) {
+#ifdef __UNIXWARE__
+    /*
+     * To retain compatibility with older config files, on UnixWare, we
+     * accept the xqueue protocol but use the normal keyboard procs.
+     */
+     xf86Info.kbdProc    = xf86KbdProc;
+     xf86Info.kbdEvents  = xf86KbdEvents;
+#else
 #ifdef XQUEUE
     xf86Info.kbdProc = xf86XqueKbdProc;
     xf86Info.kbdEvents = xf86XqueEvents;
     xf86Msg(X_CONFIG, "Xqueue selected for keyboard input\n");
+#endif
 #endif
     xfree(s);
 #ifdef WSCONS_SUPPORT
@@ -2443,12 +2473,14 @@ configExtensions(XF86ConfExtensionsPtr conf_ext)
 
 	    if (!val ||
 		xf86NameCmp(val, "enable") == 0 ||
+		xf86NameCmp(val, "enabled") == 0 ||
 		xf86NameCmp(val, "on") == 0 ||
 		xf86NameCmp(val, "1") == 0 ||
 		xf86NameCmp(val, "yes") == 0 ||
 		xf86NameCmp(val, "true") == 0) {
 		/* NOTHING NEEDED -- enabling is handled below */
 	    } else if (xf86NameCmp(val, "disable") == 0 ||
+                       xf86NameCmp(val, "disabled") == 0 ||
 		       xf86NameCmp(val, "off") == 0 ||
 		       xf86NameCmp(val, "0") == 0 ||
 		       xf86NameCmp(val, "no") == 0 ||
