@@ -1,5 +1,5 @@
 /*
- * $Id: picturestr.h,v 1.13 2005/07/03 07:02:08 daniels Exp $
+ * $Id: picturestr.h,v 1.14 2005/08/24 11:18:33 daniels Exp $
  *
  * Copyright © 2000 SuSE, Inc.
  *
@@ -23,10 +23,6 @@
  * Author:  Keith Packard, SuSE, Inc.
  */
 
-#ifdef HAVE_DIX_CONFIG_H
-#include <dix-config.h>
-#endif
-
 #ifndef _PICTURESTR_H_
 #define _PICTURESTR_H_
 
